@@ -21,8 +21,9 @@ class LambdaChat(AsyncGeneratorProvider, ProviderModelMixin):
     conversation_url = f"{url}/conversation"
 
     working = True
+    active_by_default = True
 
-    default_model = "deepseek-v3-0324"
+    default_model = "deepseek-r1"
     models = [
         "deepseek-llama3.3-70b",
         "deepseek-r1",
@@ -34,15 +35,13 @@ class LambdaChat(AsyncGeneratorProvider, ProviderModelMixin):
         "lfm-40b",
         "llama3.3-70b-instruct-fp8",
         "qwen25-coder-32b-instruct",
-        "deepseek-v3",
-        default_model,
+        "deepseek-v3-0324",
         "llama-4-maverick-17b-128e-instruct-fp8",
         "llama-4-scout-17b-16e-instruct",
         "llama3.3-70b-instruct-fp8",
         "qwen3-32b-fp8",
     ]
     model_aliases = {
-        "deepseek-v3-0324": "deepseek-v3",
         "hermes-3": "hermes3-405b-fp8-128k",
         "hermes-3-405b": ["hermes3-405b-fp8-128k", "hermes-3-llama-3.1-405b-fp8"],
         "nemotron-70b": "llama3.1-nemotron-70b-instruct",
