@@ -13,7 +13,7 @@ from .helper import filter_none, format_media_prompt
 from .base_provider import AsyncGeneratorProvider, ProviderModelMixin
 from ..typing import AsyncResult, Messages, MediaListType
 from ..image import is_data_an_audio
-from ..errors import ModelNotFoundError, MissingAuthError
+from ..errors import MissingAuthError
 from ..requests.raise_for_status import raise_for_status
 from ..requests.aiohttp import get_connector
 from ..image import use_aspect_ratio
@@ -60,8 +60,9 @@ FOLLOWUPS_DEVELOPER_MESSAGE = [{
     "role": "developer",
     "content": "Provide conversation options.",
 }]
+
 class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
-    label = "Pollinations AI"
+    label = "Pollinations AI 🌸"
     url = "https://pollinations.ai"
     login_url = "https://auth.pollinations.ai"
     active_by_default = True
@@ -82,58 +83,26 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
     default_audio_model = "openai-audio"
     default_voice = "alloy"
     text_models = [default_model, "evil"]
-    image_models = [default_image_model, "turbo", "kontext", "gptimage", "transparent"]
+    image_models = [default_image_model, "turbo", "kontext"]
     audio_models = {default_audio_model: []}
     vision_models = [default_vision_model]
     _models_loaded = False
     model_aliases = {
-        "gpt-4": "openai",
-        "gpt-4o": "openai",
-        "gpt-4.1-mini": "openai",
-        "gpt-4o-mini": "openai",
-        "gpt-4.1-nano": "openai-fast",
-        "gpt-4.1": "openai-large",
-        "o4-mini": "openai-reasoning",
-        "qwen-2.5-coder-32b": "qwen-coder",
-        "llama-3.3-70b": "llama",
         "llama-4-scout": "llamascout",
-        "mistral-small-3.1-24b": "mistral",
-        "phi-4": "phi",
         "deepseek-r1": "deepseek-reasoning",
-        "deepseek-v3-0324": "deepseek",
-        "deepseek-v3": "deepseek",
-        "grok-3-mini": "grok",
-        "grok-3-mini-high": "grok",
-        "gpt-4o-mini-audio": "openai-audio",
-        "gpt-4o-audio": "openai-audio",
         "sdxl-turbo": "turbo",
         "gpt-image": "gptimage",
         "flux-dev": "flux",
         "flux-schnell": "flux",
         "flux-pro": "flux",
         "flux": "flux",
+        "flux-kontext": "kontext",
     }
-    swap_models = {value: key for key, value in model_aliases.items()}
-
-    @classmethod
-    def get_model(cls, model: str) -> str:
-        """Get the internal model name from the user-provided model name."""
-        if not model:
-            return cls.default_model
-
-        # Check if there's an alias for this model
-        if model in cls.model_aliases:
-            return cls.model_aliases[model]
-
-        # Check if the model exists directly in our model lists
-        if model in cls.text_models or model in cls.image_models or model in cls.audio_models:
-            return model
-
-        # If no match is found, raise an error
-        raise ModelNotFoundError(f"PollinationsAI: Model {model} not found")
 
     @classmethod
     def get_models(cls, **kwargs):
+        def get_alias(model: dict) -> str:
+            return model.get("aliases", model.get("name")).replace("-instruct", "").replace("qwen-", "qwen").replace("qwen", "qwen-")
         if not cls._models_loaded:
             try:
                 # Update of image models
@@ -168,27 +137,19 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
                         cls.audio_models.update({alias: {}})
 
                 cls.vision_models.extend([
-                    cls.swap_models.get(model.get("name"), model.get("name"))
+                    get_alias(model)
                     for model in models
-                    if model.get("vision") and model not in cls.vision_models
+                    if model.get("vision") and get_alias(model) not in cls.vision_models
                 ])
-                for alias, model in cls.model_aliases.items():
-                    if model in cls.vision_models and alias not in cls.vision_models:
-                        cls.vision_models.append(alias)
 
-                # Create a set of unique text models starting with default model
-                text_models = cls.text_models.copy()
-
-                # Add models from the API response
                 for model in models:
-                    model_name = model.get("name")
-                    if model_name and "input_modalities" in model and "text" in model["input_modalities"]:
-                        text_models.append(cls.swap_models.get(model_name, model_name))
-
-                # Convert to list and update text_models
-                cls.text_models = list(dict.fromkeys(text_models))
-
-                cls._models_loaded = True
+                    alias = get_alias(model)
+                    if alias not in cls.text_models:
+                        cls.text_models.append(alias)
+                        if alias != model.get("name"):
+                            cls.model_aliases[alias] = model.get("name")
+                    elif model.get("name") not in cls.text_models:
+                        cls.text_models.append(model.get("name"))
 
             except Exception as e:
                 # Save default models in case of an error
@@ -198,6 +159,9 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
                     cls.image_models = [cls.default_image_model]
                 debug.error(f"Failed to fetch models: {e}")
 
+            finally:
+                cls._models_loaded = True
+
         # Return unique models across all categories
         all_models = cls.text_models.copy()
         all_models.extend(cls.image_models)
@@ -261,10 +225,10 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
                         has_audio = True
                         break
             model = cls.default_audio_model if has_audio else model
-        try:
-            model = cls.get_model(model) if model else None
-        except ModelNotFoundError:
-            pass
+        elif cls._models_loaded or cls.get_models():
+            if model in cls.model_aliases:
+                model = cls.model_aliases[model]
+        debug.log(f"Using model: {model}")
         if model in cls.image_models:
             async for chunk in cls._generate_image(
                 model="gptimage" if model == "transparent" else model,
@@ -385,11 +349,10 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
             timeout=ClientTimeout(timeout)
         ) as session:
             responses = set()
-            responses.add(Reasoning(label=f"Generating {n} {'image' if n == 1 else 'images'}"))
+            yield Reasoning(label=f"Generating {n} {'image' if n == 1 else 'images'}")
             finished = 0
             start = time.time()
             async def get_image(responses: set, i: int, seed: Optional[int] = None):
-                nonlocal finished
                 try:
                     async with session.get(get_url_with_seed(i, seed), allow_redirects=False, headers=headers) as response:
                         await raise_for_status(response)
@@ -397,22 +360,24 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
                     responses.add(e)
                     debug.error(f"Error fetching image: {e}")
                 responses.add(ImageResponse(str(response.url), prompt, {"headers": headers}))
-                finished += 1
-                responses.add(Reasoning(label=f"Image {finished}/{n} generated in {time.time() - start:.2f}s"))
             tasks: list[asyncio.Task] = []
             for i in range(int(n)):
                 tasks.append(asyncio.create_task(get_image(responses, i, seed)))
             while finished < n or len(responses) > 0:
                 while len(responses) > 0:
                     item = responses.pop()
-                    if isinstance(item, Exception) and finished < 2:
-                        yield Reasoning(status="")
-                        for task in tasks:
-                            task.cancel()
-                        if cls.login_url in str(item):
-                            raise MissingAuthError(item)
-                        raise item
-                    yield item
+                    if isinstance(item, Exception):
+                        if finished < 2:
+                            yield Reasoning(status="")
+                            for task in tasks:
+                                task.cancel()
+                            if cls.login_url in str(item):
+                                raise MissingAuthError(item)
+                            raise item
+                    else: 
+                        finished += 1
+                        yield Reasoning(label=f"Image {finished}/{n} generated in {time.time() - start:.2f}s")
+                        yield item
                 await asyncio.sleep(1)
             yield Reasoning(status="")
             await asyncio.gather(*tasks)
@@ -479,7 +444,7 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
                     yield chunk
                 if full_resposne:
                     full_content = "".join(full_resposne)
-                    if kwargs.get("action") == "next":
+                    if kwargs.get("action") == "next" and model != "evil":
                         tool_messages = []
                         for message in messages:
                             if message.get("role") == "user":
