@@ -3,10 +3,8 @@ from __future__ import annotations
 import os
 from typing import AsyncIterator
 
-from ..base_provider import AsyncAuthedProvider
 from ..Copilot import Copilot, readHAR, has_nodriver, get_access_token_and_cookies
 from ...providers.response import AuthResult, RequestLogin
-from ...typing import AsyncResult, Messages
 from ...errors import NoValidHarFileError
 from ... import debug
 
@@ -16,6 +14,12 @@ class CopilotAccount(Copilot):
     parent = "Copilot"
     default_model = "Copilot"
     default_vision_model = default_model
+    model_aliases = {
+        "gpt-4": default_model,
+        "gpt-4o": default_model,
+        "o1": "Think Deeper",
+        "dall-e-3": default_model
+    }
 
     @classmethod
     async def on_auth_async(cls, proxy: str = None, **kwargs) -> AsyncIterator:
