@@ -10,7 +10,7 @@ from .HuggingChat import HuggingChat
 from .HuggingFaceAPI import HuggingFaceAPI
 from .HuggingFaceInference import HuggingFaceInference
 from .HuggingFaceMedia import HuggingFaceMedia
-from .models import model_aliases, image_model_aliases, vision_models, default_vision_model
+from .models import model_aliases, image_model_aliases, vision_models, default_model
 from .... import debug
 
 class HuggingFace(AsyncGeneratorProvider, ProviderModelMixin):
@@ -28,7 +28,7 @@ class HuggingFace(AsyncGeneratorProvider, ProviderModelMixin):
 
     model_aliases = {**model_aliases, **image_model_aliases}
     vision_models = vision_models
-    default_vision_model = default_vision_model
+    default_model = default_model
 
     @classmethod
     async def create_async_generator(
@@ -39,19 +39,19 @@ class HuggingFace(AsyncGeneratorProvider, ProviderModelMixin):
     ) -> AsyncResult:
         if model in cls.model_aliases:
             model = cls.model_aliases[model]
-        if "tools" not in kwargs and "media" not in kwargs and random.random() >= 0.5:
-            try:
-                is_started = False
-                async for chunk in HuggingFaceInference.create_async_generator(model, messages, **kwargs):
-                    if isinstance(chunk, (str, ImageResponse)):
-                        is_started = True
-                    yield chunk
-                if is_started:
-                    return
-            except Exception as e:
-                if is_started:
-                    raise e
-                debug.error(f"{cls.__name__} {type(e).__name__}; {e}")
+        # if "tools" not in kwargs and "media" not in kwargs and random.random() >= 0.5:
+        #     try:
+        #         is_started = False
+        #         async for chunk in HuggingFaceInference.create_async_generator(model, messages, **kwargs):
+        #             if isinstance(chunk, (str, ImageResponse)):
+        #                 is_started = True
+        #             yield chunk
+        #         if is_started:
+        #             return
+        #     except Exception as e:
+        #         if is_started:
+        #             raise e
+        #         debug.error(f"{cls.__name__} {type(e).__name__}; {e}")
         if not cls.image_models:
             cls.get_models()
         try:
@@ -60,14 +60,14 @@ class HuggingFace(AsyncGeneratorProvider, ProviderModelMixin):
             return
         except ModelNotFoundError:
             pass
-        if model in cls.image_models:
-            if "api_key" not in kwargs:
-                async for chunk in HuggingChat.create_async_generator(model, messages, **kwargs):
-                    yield chunk
-            else:
-                async for chunk in HuggingFaceInference.create_async_generator(model, messages, **kwargs):
-                    yield chunk
-            return
+        # if model in cls.image_models:
+        #     if "api_key" not in kwargs:
+        #         async for chunk in HuggingChat.create_async_generator(model, messages, **kwargs):
+        #             yield chunk
+        #     else:
+        #         async for chunk in HuggingFaceInference.create_async_generator(model, messages, **kwargs):
+        #             yield chunk
+        #     return
         try:
             async for chunk in HuggingFaceAPI.create_async_generator(model, messages, **kwargs):
                 yield chunk
