@@ -5,12 +5,13 @@ import requests
 from ..helper import filter_none, format_media_prompt
 from ..base_provider import AsyncGeneratorProvider, ProviderModelMixin, RaiseErrorMixin
 from ...typing import Union, AsyncResult, Messages, MediaListType
-from ...requests import StreamSession, StreamResponse, raise_for_status, see_stream
+from ...requests import StreamSession, StreamResponse, raise_for_status, sse_stream
 from ...image import use_aspect_ratio
 from ...image.copy_images import save_response_media
 from ...providers.response import FinishReason, ToolCalls, Usage, ImageResponse, ProviderInfo, AudioResponse, Reasoning
 from ...tools.media import render_messages
-from ...errors import MissingAuthError, ResponseError
+from ...tools.run_tools import AuthManager
+from ...errors import MissingAuthError
 from ... import debug
 
 class OpenaiTemplate(AsyncGeneratorProvider, ProviderModelMixin, RaiseErrorMixin):
@@ -22,7 +23,11 @@ class OpenaiTemplate(AsyncGeneratorProvider, ProviderModelMixin, RaiseErrorMixin
     default_model = ""
     fallback_models = []
     sort_models = True
+    models_needs_auth = False
+    use_model_names = False
     ssl = None
+    add_user = True
+    use_image_size = False
 
     @classmethod
     def get_models(cls, api_key: str = None, api_base: str = None) -> list[str]:
@@ -33,16 +38,21 @@ class OpenaiTemplate(AsyncGeneratorProvider, ProviderModelMixin, RaiseErrorMixin
                     api_base = cls.api_base
                 if api_key is None and cls.api_key is not None:
                     api_key = cls.api_key
+                if not api_key:
+                    api_key = AuthManager.load_api_key(cls)
+                if cls.models_needs_auth and not api_key:
+                    raise MissingAuthError('Add a "api_key"')
                 if api_key is not None:
                     headers["authorization"] = f"Bearer {api_key}"
                 response = requests.get(f"{api_base}/models", headers=headers, verify=cls.ssl)
                 raise_for_status(response)
                 data = response.json()
                 data = data.get("data") if isinstance(data, dict) else data
-                cls.image_models = [model.get("id") for model in data if model.get("image")]
+                cls.image_models = [model.get("name") if cls.use_model_names else model.get("id", model.get("name")) for model in data if model.get("image") or model.get("type") == "image" or model.get("supports_images")]
                 cls.vision_models = cls.vision_models.copy()
-                cls.vision_models += [model.get("id") for model in data if model.get("vision")]
-                cls.models = [model.get("id") for model in data]
+                cls.vision_models += [model.get("name") if cls.use_model_names else model.get("id", model.get("name")) for model in data if model.get("vision")]
+                cls.models = [model.get("name") if cls.use_model_names else model.get("id", model.get("name")) for model in data]
+                cls.models_count = {model.get("name") if cls.use_model_names else model.get("id", model.get("name")): len(model.get("providers", [])) for model in data if len(model.get("providers", [])) > 1}
                 if cls.sort_models:
                     cls.models.sort()
             except Exception as e:
@@ -67,10 +77,11 @@ class OpenaiTemplate(AsyncGeneratorProvider, ProviderModelMixin, RaiseErrorMixin
         stop: Union[str, list[str]] = None,
         stream: bool = None,
         prompt: str = None,
+        user: str = None,
         headers: dict = None,
         impersonate: str = None,
         download_media: bool = True,
-        extra_parameters: list[str] = ["tools", "parallel_tool_calls", "tool_choice", "reasoning_effort", "logit_bias", "modalities", "audio"],
+        extra_parameters: list[str] = ["tools", "parallel_tool_calls", "tool_choice", "reasoning_effort", "logit_bias", "modalities", "audio", "stream_options"],
         extra_body: dict = None,
         **kwargs
     ) -> AsyncResult:
@@ -91,11 +102,10 @@ class OpenaiTemplate(AsyncGeneratorProvider, ProviderModelMixin, RaiseErrorMixin
             # Proxy for image generation feature
             if model and model in cls.image_models:
                 prompt = format_media_prompt(messages, prompt)
-                data = {
-                    "prompt": prompt,
-                    "model": model,
-                    **use_aspect_ratio({"width": kwargs.get("width"), "height": kwargs.get("height")}, kwargs.get("aspect_ratio", None))
-                }
+                size = use_aspect_ratio({"width": kwargs.get("width"), "height": kwargs.get("height")}, kwargs.get("aspect_ratio", None))
+                size = {"size": f"{size['width']}x{size['height']}", **size} if cls.use_image_size and "width" in size and "height" in size else size
+                data = {"prompt": prompt, "model": model, **size}
+
                 # Handle media if provided
                 if media is not None:
                     data["image_url"] = next(iter([data for data, _ in media if data and isinstance(data, str) and data.startswith("http://") or data.startswith("https://")]), None)
@@ -120,13 +130,15 @@ class OpenaiTemplate(AsyncGeneratorProvider, ProviderModelMixin, RaiseErrorMixin
                 top_p=top_p,
                 stop=stop,
                 stream="audio" not in extra_parameters if stream is None else stream,
+                user=user if cls.add_user else None,
                 **extra_parameters,
                 **extra_body
             )
             if api_endpoint is None:
-                api_endpoint = cls.api_endpoint
-                if api_endpoint is None:
+                if api_base:
                     api_endpoint = f"{api_base.rstrip('/')}/chat/completions"
+                if api_endpoint is None:
+                    api_endpoint = cls.api_endpoint
             async with session.post(api_endpoint, json=data, ssl=cls.ssl) as response:
                 async for chunk in read_response(response, stream, prompt, cls.get_dict(), download_media):
                     yield chunk
@@ -163,14 +175,15 @@ async def read_response(response: StreamResponse, stream: bool, prompt: str, pro
                 yield message["content"].strip()
             if "tool_calls" in message:
                 yield ToolCalls(message["tool_calls"])
+            if choice:
+                reasoning_content = choice.get("delta", {}).get("reasoning_content", choice.get("delta", {}).get("reasoning"))
+                if reasoning_content:
+                    yield Reasoning(reasoning_content, status="")
             audio = message.get("audio", {})
             if "data" in audio:
                 if download_media:
-                    async for chunk in save_response_media(audio["data"], prompt, [model]):
+                    async for chunk in save_response_media(audio, prompt, [model]):
                         yield chunk
-                    if "transcript" in audio:
-                        yield "\n\n"
-                        yield audio["transcript"]
                 else:
                     yield AudioResponse(f"data:audio/mpeg;base64,{audio['data']}", transcript=audio.get("transcript"))
             if choice and "finish_reason" in choice and choice["finish_reason"] is not None:
@@ -181,37 +194,35 @@ async def read_response(response: StreamResponse, stream: bool, prompt: str, pro
         reasoning = False
         first = True
         model_returned = False
-        async for data in see_stream(response):
+        async for data in sse_stream(response):
             OpenaiTemplate.raise_error(data)
             model = data.get("model")
             if not model_returned and model:
                 yield ProviderInfo(**provider_info, model=model)
                 model_returned = True
             choice = next(iter(data["choices"]), None)
-            if not choice:
-                continue
-            if "content" in choice["delta"] and choice["delta"]["content"]:
-                delta = choice["delta"]["content"]
-                if first:
-                    delta = delta.lstrip()
-                if delta:
-                    first = False
-                    if reasoning:
-                        yield Reasoning(status="")
-                        reasoning = False
-                    yield delta
-            tool_calls = choice.get("delta", {}).get("tool_calls")
-            if tool_calls:
-                yield ToolCalls(choice["delta"]["tool_calls"])
-            reasoning_content = choice.get("delta", {}).get("reasoning_content")
-            if reasoning_content:
-                reasoning = True
-                yield Reasoning(reasoning_content)
+            if choice:
+                content = choice.get("delta", {}).get("content")
+                if content:
+                    if first:
+                        content = content.lstrip()
+                    if content:
+                        first = False
+                        if reasoning:
+                            yield Reasoning(status="")
+                            reasoning = False
+                        yield content
+                tool_calls = choice.get("delta", {}).get("tool_calls")
+                if tool_calls:
+                    yield ToolCalls(tool_calls)
+                reasoning_content = choice.get("delta", {}).get("reasoning_content", choice.get("delta", {}).get("reasoning"))
+                if reasoning_content:
+                    reasoning = True
+                    yield Reasoning(reasoning_content)
             if "usage" in data and data["usage"]:
                 yield Usage(**data["usage"])
             if choice and choice.get("finish_reason") is not None:
                 yield FinishReason(choice["finish_reason"])
-                break
     else:
         await raise_for_status(response)
         async for chunk in save_response_media(response, prompt, [model]):
