@@ -12,6 +12,7 @@ from email.utils import formatdate
 import os.path
 import hashlib
 import asyncio
+import base64
 from contextlib import asynccontextmanager
 from urllib.parse import quote_plus
 from fastapi import FastAPI, Response, Request, UploadFile, Form, Depends, Header
@@ -97,6 +98,7 @@ async def lifespan(app: FastAPI):
     # Read cookie files if not ignored
     if not AppConfig.ignore_cookie_files:
         read_cookie_files()
+    AppConfig.g4f_api_key = os.environ.get("G4F_API_KEY", AppConfig.g4f_api_key)
     yield
     if has_nodriver:
         for browser in util.get_registered_instances():
@@ -187,7 +189,8 @@ class AppConfig:
     @classmethod
     def set_config(cls, **data):
         for key, value in data.items():
-            setattr(cls, key, value)
+            if value is not None:
+                setattr(cls, key, value)
 
 def update_headers(request: Request, user: str) -> Request:
     new_headers = request.headers.mutablecopy()
@@ -238,7 +241,7 @@ class Api:
                     user_g4f_api_key = await self.security(request)
                     if hasattr(user_g4f_api_key, "credentials"):
                         user_g4f_api_key = user_g4f_api_key.credentials
-                if AppConfig.g4f_api_key is None or not secrets.compare_digest(AppConfig.g4f_api_key, user_g4f_api_key):
+                if AppConfig.g4f_api_key is None or not user_g4f_api_key or not secrets.compare_digest(AppConfig.g4f_api_key, user_g4f_api_key):
                     if has_crypto and user_g4f_api_key:
                         try:
                             expires, user = decrypt_data(private_key, user_g4f_api_key).split(":", 1)
@@ -247,10 +250,14 @@ class Api:
                                 data = json.loads(decrypt_data(session_key, user_g4f_api_key))
                                 expires = int(decrypt_data(private_key, data["data"])) + 86400
                                 user = data.get("user", user)
+                                if not user:
+                                    raise ValueError("User not found")
                             except:
                                 return ErrorResponse.from_message(f"Invalid G4F API key", HTTP_401_UNAUTHORIZED)
                         expires = int(expires) - int(time.time())
-                        debug.log(f"User: '{user}' G4F API key expires in {expires} seconds")
+                        hours, remainder = divmod(expires, 3600)
+                        minutes, seconds = divmod(remainder, 60)
+                        debug.log(f"User: '{user}' G4F API key expires in {hours}h {minutes}m {seconds}s")
                         if expires < 0:
                             return ErrorResponse.from_message("G4F API key expired", HTTP_401_UNAUTHORIZED)
                 else:
@@ -266,15 +273,16 @@ class Api:
                     if user_g4f_api_key is not None:
                         if user is None:
                             return ErrorResponse.from_message("Invalid G4F API key", HTTP_403_FORBIDDEN)
-                    elif path.startswith("/backend-api/") or path.startswith("/chat/") and path != "/chat/":
+                    elif path.startswith("/backend-api/") or path.startswith("/chat/"):
                         try:
                             user = await self.get_username(request)
                         except HTTPException as e:
                             return ErrorResponse.from_message(e.detail, e.status_code, e.headers)
                 if user is None:
                     ip = request.headers.get("X-Forwarded-For", "")[:4].strip(":.")
-                    user = request.headers.get("Cf-Ipcountry", "")
-                    user = f"{user}:{ip}" if user else ip
+                    country = request.headers.get("Cf-Ipcountry", "")
+                    user = request.headers.get("x-user", ip)
+                    user = f"{country}:{user}" if country else user
                 request = update_headers(request, user)
             response = await call_next(request)
             return response
@@ -360,6 +368,9 @@ class Api:
                     "owned_by": getattr(provider, "label", provider.__name__),
                     "image": model in getattr(provider, "image_models", []),
                     "vision": model in getattr(provider, "vision_models", []),
+                    "audio": model in getattr(provider, "audio_models", []),
+                    "video": model in getattr(provider, "video_models", []),
+                    "type": "image" if model in getattr(provider, "image_models", []) else "text",
                 } for model in models]
             }
 
@@ -390,6 +401,8 @@ class Api:
             HTTP_500_INTERNAL_SERVER_ERROR: {"model": ErrorResponseModel},
         }
         @self.app.post("/v1/chat/completions", responses=responses)
+        @self.app.post("/api/{provider}/chat/completions", responses=responses)
+        @self.app.post("/api/{provider}/{conversation_id}/chat/completions", responses=responses)
         async def chat_completions(
             config: ChatCompletionsConfig,
             credentials: Annotated[HTTPAuthorizationCredentials, Depends(Api.security)] = None,
@@ -480,14 +493,6 @@ class Api:
                 logger.exception(e)
                 return ErrorResponse.from_exception(e, config, HTTP_500_INTERNAL_SERVER_ERROR)
 
-        @self.app.post("/api/{provider}/chat/completions", responses=responses)
-        async def provider_chat_completions(
-            provider: str,
-            config: ChatCompletionsConfig,
-            credentials: Annotated[HTTPAuthorizationCredentials, Depends(Api.security)] = None,
-        ):
-            return await chat_completions(config, credentials, provider)
-
         responses = {
             HTTP_200_OK: {"model": ClientResponse},
             HTTP_401_UNAUTHORIZED: {"model": ErrorResponseModel},
@@ -540,15 +545,6 @@ class Api:
         ):
             return await v1_responses(config, credentials, provider)
 
-        @self.app.post("/api/{provider}/{conversation_id}/chat/completions", responses=responses)
-        async def provider_chat_completions(
-            provider: str,
-            conversation_id: str,
-            config: ChatCompletionsConfig,
-            credentials: Annotated[HTTPAuthorizationCredentials, Depends(Api.security)] = None,
-        ):
-            return await chat_completions(config, credentials, provider, conversation_id)
-
         responses = {
             HTTP_200_OK: {"model": ImagesResponse},
             HTTP_401_UNAUTHORIZED: {"model": ErrorResponseModel},
@@ -634,11 +630,12 @@ class Api:
         }
         @self.app.post("/v1/audio/transcriptions", responses=responses)
         @self.app.post("/api/{path_provider}/audio/transcriptions", responses=responses)
+        @self.app.post("/api/markitdown", responses=responses)
         async def convert(
             file: UploadFile,
             path_provider: str = None,
             model: Annotated[Optional[str], Form()] = None,
-            provider: Annotated[Optional[str], Form()] = None,
+            provider: Annotated[Optional[str], Form()] = "MarkItDown",
             prompt: Annotated[Optional[str], Form()] = "Transcribe this audio"
         ):
             provider = provider if path_provider is None else path_provider
@@ -666,12 +663,6 @@ class Api:
                 logger.exception(e)
                 return ErrorResponse.from_exception(e, None, HTTP_500_INTERNAL_SERVER_ERROR)
 
-        @self.app.post("/api/markitdown", responses=responses)
-        async def markitdown(
-            file: UploadFile
-        ):
-            return await convert(file, "MarkItDown")
-
         responses = {
             HTTP_200_OK: {"content": {"audio/*": {}}},
             HTTP_401_UNAUTHORIZED: {"model": ErrorResponseModel},
@@ -679,7 +670,7 @@ class Api:
             HTTP_500_INTERNAL_SERVER_ERROR: {"model": ErrorResponseModel},
         }
         @self.app.post("/v1/audio/speech", responses=responses)
-        @self.app.post("/api/{path_provider}/audio/speech", responses=responses)
+        @self.app.post("/api/{provider}/audio/speech", responses=responses)
         async def generate_speech(
             config: AudioSpeechConfig,
             provider: str = AppConfig.media_provider,
@@ -689,6 +680,7 @@ class Api:
             if credentials is not None and credentials.credentials != "secret":
                 api_key = credentials.credentials
             try:
+                audio = filter_none(voice=config.voice, format=config.response_format, language=config.language)
                 response = await self.client.chat.completions.create(
                     messages=[
                         {"role": "user", "content": f"{config.instrcutions} Text: {config.input}"}
@@ -696,10 +688,16 @@ class Api:
                     model=config.model,
                     provider=config.provider if provider is None else provider,
                     prompt=config.input,
-                    audio=filter_none(voice=config.voice, format=config.response_format, language=config.language),
                     api_key=api_key,
+                    download_media=config.download_media,
+                    **filter_none(
+                        audio=audio if audio else None,
+                    )
                 )
-                if isinstance(response.choices[0].message.content, AudioResponse):
+                if response.choices[0].message.audio is not None:
+                    response = base64.b64decode(response.choices[0].message.audio.data)
+                    return Response(response, media_type=f"audio/{config.response_format.replace('mp3', 'mpeg')}")
+                elif isinstance(response.choices[0].message.content, AudioResponse):
                     response = response.choices[0].message.content.data
                     response = response.replace("/media", get_media_dir())
                     def delete_file():
