@@ -67,7 +67,7 @@ def iter_response(
     stop: Optional[list[str]] = None
 ) -> ChatCompletionResponseType:
     content = ""
-    reasoning_content = []
+    reasoning = []
     finish_reason = None
     tool_calls = None
     usage = None
@@ -97,7 +97,7 @@ def iter_response(
             provider = chunk
             continue
         elif isinstance(chunk, Reasoning):
-            reasoning_content.append(chunk)
+            reasoning.append(chunk)
         elif isinstance(chunk, HiddenResponse):
             continue
         elif isinstance(chunk, Exception):
@@ -145,7 +145,7 @@ def iter_response(
             content, finish_reason, completion_id, int(time.time()), usage=usage,
             **filter_none(tool_calls=[ToolCallModel.model_construct(**tool_call) for tool_call in tool_calls]) if tool_calls is not None else {},
             conversation=None if conversation is None else conversation.get_dict(),
-            reasoning_content=reasoning_content if reasoning_content else None
+            reasoning=reasoning if reasoning else None
         )
     if provider is not None:
         chat_completion.provider = provider.name
@@ -172,7 +172,7 @@ async def async_iter_response(
     stop: Optional[list[str]] = None
 ) -> AsyncChatCompletionResponseType:
     content = ""
-    reasoning_content = []
+    reasoning = []
     finish_reason = None
     completion_id = ''.join(random.choices(string.ascii_letters + string.digits, k=28))
     idx = 0
@@ -200,7 +200,7 @@ async def async_iter_response(
                 provider = chunk
                 continue
             elif isinstance(chunk, Reasoning) and not stream:
-                reasoning_content.append(chunk)
+                reasoning.append(chunk)
             elif isinstance(chunk, HiddenResponse):
                 continue
             elif isinstance(chunk, Exception):
@@ -250,7 +250,7 @@ async def async_iter_response(
                     tool_calls=[ToolCallModel.model_construct(**tool_call) for tool_call in tool_calls]
                 ) if tool_calls is not None else {},
                 conversation=conversation,
-                reasoning_content=reasoning_content if reasoning_content else None
+                reasoning=reasoning if reasoning else None
             )
         if provider is not None:
             chat_completion.provider = provider.name
@@ -365,7 +365,7 @@ class Completions:
             messages = [{"role": "user", "content": messages}]
         resolve_media(kwargs, image, image_name)
         if hasattr(model, "name"):
-            model = model.name
+            model = model.get_long_name()
         if provider is None:
             provider = self.provider
             if provider is None:
@@ -686,7 +686,7 @@ class AsyncCompletions:
             messages = [{"role": "user", "content": messages}]
         resolve_media(kwargs, image, image_name)
         if hasattr(model, "name"):
-            model = model.name
+            model = model.get_long_name()
         if provider is None:
             provider = self.provider
             if provider is None:
@@ -781,7 +781,7 @@ class AsyncResponses():
                     input[idx] = {"role": message["role"], "content": message["content"]}
         resolve_media(kwargs)
         if hasattr(model, "name"):
-            model = model.name
+            model = model.get_long_name()
         if provider is None:
             provider = self.provider
             if provider is None:
