@@ -4,6 +4,7 @@ import json
 import flask
 import os
 import time
+import base64
 import logging
 import asyncio
 import shutil
@@ -11,6 +12,7 @@ import random
 import datetime
 from hashlib import sha256
 from urllib.parse import quote_plus
+from functools import lru_cache
 from flask import Flask, Response, redirect, request, jsonify, send_from_directory
 from werkzeug.exceptions import NotFound
 from typing import Generator
@@ -40,7 +42,7 @@ from ...providers.response import FinishReason, AudioResponse, MediaResponse, Re
 from ...client.helper import filter_markdown
 from ...tools.files import supports_filename, get_streaming, get_bucket_dir, get_tempfile
 from ...tools.run_tools import iter_run_tools
-from ...errors import ProviderNotFoundError
+from ...errors import ProviderNotFoundError, MissingAuthError
 from ...image import is_allowed_extension, process_image, MEDIA_TYPE_MAP
 from ...cookies import get_cookies_dir
 from ...image.copy_images import secure_filename, get_source_url, get_media_dir, copy_media
@@ -107,6 +109,14 @@ class Backend_Api(Api):
 
             @app.route('/backend-api/v2/public-key', methods=['GET'])
             def get_public_key():
+                if not has_crypto:
+                    return jsonify({"error": {"message": "Crypto support is not available"}}), 501
+                # try:
+                #     diff = time.time() - int(base64.b64decode(request.cookies.get("fingerprint")).decode())
+                # except Exception as e:
+                #     return jsonify({"error": {"message": "Invalid fingerprint"}}), 403
+                # if diff > 60 * 60 * 2:
+                #     return jsonify({"error": {"message": "Please refresh the page"}}), 403
                 # Send the public key to the client for encryption
                 return jsonify({
                     "public_key": public_key_pem.decode(),
@@ -114,13 +124,21 @@ class Backend_Api(Api):
                 })
 
         @app.route('/backend-api/v2/models', methods=['GET'])
-        def jsonify_models(**kwargs):
-            response = get_demo_models() if app.demo else self.get_models(**kwargs)
-            return jsonify(response)
+        @lru_cache(maxsize=1)
+        def jsonify_models():
+            return jsonify(self.get_all_models())
 
         @app.route('/backend-api/v2/models/<provider>', methods=['GET'])
         def jsonify_provider_models(**kwargs):
-            response = self.get_provider_models(**kwargs)
+            try:
+                response = self.get_provider_models(**kwargs)
+                if response is None:
+                    return jsonify({"error": {"message": "Provider not found"}}), 404
+            except MissingAuthError as e:
+                return jsonify({"error": {"message": f"{type(e).__name__}: {e}"}}), 401
+            except Exception as e:
+                logger.exception(e)
+                return jsonify({"error": {"message": f"{type(e).__name__}: {e}"}}), 500
             return jsonify(response)
 
         @app.route('/backend-api/v2/providers', methods=['GET'])
@@ -208,8 +226,9 @@ class Backend_Api(Api):
             cache_dir = Path(get_cookies_dir()) / ".usage"
             cache_file = cache_dir / f"{datetime.date.today()}.jsonl"
             cache_dir.mkdir(parents=True, exist_ok=True)
+            data = {**request.json, "user": request.headers.get("x-user", "unknown")}
             with cache_file.open("a" if cache_file.exists() else "w") as f:
-                f.write(f"{json.dumps(request.json)}\n")
+                f.write(f"{json.dumps(data)}\n")
             return {}
     
         @app.route('/backend-api/v2/usage/<date>', methods=['GET'])
@@ -261,10 +280,6 @@ class Backend_Api(Api):
             )
 
         self.routes = {
-            '/backend-api/v2/version': {
-                'function': self.get_version,
-                'methods': ['GET']
-            },
             '/backend-api/v2/synthesize/<provider>': {
                 'function': self.handle_synthesize,
                 'methods': ['GET']
@@ -283,6 +298,12 @@ class Backend_Api(Api):
             },
         }
 
+        @app.route('/backend-api/v2/version', methods=['GET'])
+        def version():
+            resp = jsonify(self.get_version())
+            resp.set_cookie('fingerprint', base64.b64encode(str(int(time.time())).encode()).decode(), max_age=60 * 60 *2, httponly=True, secure=True)
+            return resp
+
         @app.route('/backend-api/v2/create', methods=['GET'])
         def create():
             try:
@@ -590,10 +611,7 @@ class Backend_Api(Api):
         api_key = request.headers.get("x_api_key")
         api_base = request.headers.get("x_api_base")
         ignored = request.headers.get("x_ignored", "").split()
-        models = super().get_provider_models(provider, api_key, api_base, ignored)
-        if models is None:
-            return "Provider not found", 404
-        return models
+        return super().get_provider_models(provider, api_key, api_base, ignored)
 
     def _format_json(self, response_type: str, content = None, **kwargs) -> str:
         """
