@@ -12,11 +12,12 @@ from .Provider import (
     Copilot,
     DeepInfraChat,
     Free2GPT,
+    GptOss,
     HuggingSpace,
     Grok,
     DeepseekAI_JanusPro7b,
-    DeepSeekAPI,
     ImageLabs,
+    Kimi,
     LambdaChat,
     OIVSCodeSer2,
     OIVSCodeSer0501,
@@ -32,18 +33,23 @@ from .Provider import (
     Yqcloud,
     
     ### Needs Auth ###
+    Azure,
     BingCreateImages,
     CopilotAccount,
     Gemini,
+    GeminiCLI,
     GeminiPro,
     HuggingChat,
     HuggingFace,
     HuggingFaceMedia,
     HuggingFaceAPI,
+    LMArenaBeta,
+    Groq,
     MetaAI,
     MicrosoftDesigner,
     OpenaiAccount,
     OpenaiChat,
+    OpenRouter,
 )
 
 class ModelRegistry:
@@ -115,6 +121,11 @@ class Model:
     name: str
     base_provider: str
     best_provider: ProviderType = None
+    long_name: Optional[str] = None
+
+    def get_long_name(self) -> str:
+        """Get the long name of the model, if available."""
+        return self.long_name if self.long_name else self.name
 
     def __post_init__(self):
         """Auto-register model after initialization"""
@@ -186,24 +197,24 @@ default_vision = VisionModel(
 gpt_4 = Model(
     name          = 'gpt-4',
     base_provider = 'OpenAI',
-    best_provider = IterListProvider([Blackbox, PollinationsAI, Copilot, Yqcloud, WeWordle, OpenaiChat])
+    best_provider = IterListProvider([Blackbox, Copilot, Yqcloud, WeWordle, OpenaiChat])
 )
 
 # gpt-4o
 gpt_4o = VisionModel(
     name          = 'gpt-4o',
     base_provider = 'OpenAI',
-    best_provider = IterListProvider([Blackbox, PollinationsAI, OpenaiChat])
+    best_provider = IterListProvider([Blackbox, OpenaiChat])
 )
 
 gpt_4o_mini = Model(
     name          = 'gpt-4o-mini',
     base_provider = 'OpenAI',
-    best_provider = IterListProvider([Blackbox, PollinationsAI, Chatai, OIVSCodeSer2, Startnest, OpenaiChat])
+    best_provider = IterListProvider([Blackbox, Chatai, OIVSCodeSer2, Startnest, OpenaiChat])
 )
 
 gpt_4o_mini_audio = AudioModel(
-    name          = 'gpt-4o-mini-audio',
+    name          = 'gpt-4o-mini-audio-preview',
     base_provider = 'OpenAI',
     best_provider = PollinationsAI
 )
@@ -244,7 +255,7 @@ o3_mini_high = Model(
 o4_mini = Model(
     name          = 'o4-mini',
     base_provider = 'OpenAI',
-    best_provider = IterListProvider([PollinationsAI, OpenaiChat])
+    best_provider = OpenaiChat
 )
 
 o4_mini_high = Model(
@@ -263,7 +274,7 @@ gpt_4_1 = Model(
 gpt_4_1_mini = Model(
     name          = 'gpt-4.1-mini',
     base_provider = 'OpenAI',
-    best_provider = IterListProvider([Blackbox, OIVSCodeSer0501, PollinationsAI])
+    best_provider = IterListProvider([Blackbox, OIVSCodeSer0501])
 )
 
 gpt_4_1_nano = Model(
@@ -278,6 +289,13 @@ gpt_4_5 = Model(
     best_provider = OpenaiChat
 )
 
+gpt_oss_120b = Model(
+    name          = 'gpt-oss-120b',
+    long_name     = 'openai/gpt-oss-120b',
+    base_provider = 'OpenAI',
+    best_provider = IterListProvider([GptOss, Together, DeepInfraChat, HuggingFace, OpenRouter, Groq])
+)
+
 # dall-e
 dall_e_3 = ImageModel(
     name = 'dall-e-3',
@@ -372,7 +390,7 @@ llama_3_2_90b = Model(
 llama_3_3_70b = Model(
     name          = "llama-3.3-70b",
     base_provider = "Meta Llama",
-    best_provider = IterListProvider([DeepInfraChat, LambdaChat, PollinationsAI, Together, HuggingChat, HuggingFace])
+    best_provider = IterListProvider([DeepInfraChat, LambdaChat, Together, HuggingChat, HuggingFace])
 )
 
 # llama-4
@@ -438,7 +456,7 @@ phi_3_5_mini = Model(
 phi_4 = Model(
     name          = "phi-4",
     base_provider = "Microsoft",
-    best_provider = IterListProvider([DeepInfraChat, PollinationsAI, HuggingSpace])
+    best_provider = IterListProvider([DeepInfraChat, HuggingSpace])
 )
 
 phi_4_multimodal = VisionModel(
@@ -510,13 +528,13 @@ gemini_2_0_flash_thinking_with_apps = Model(
 gemini_2_5_flash = Model(
     name          = 'gemini-2.5-flash',
     base_provider = 'Google',
-    best_provider = IterListProvider([Gemini, GeminiPro])
+    best_provider = IterListProvider([Gemini, GeminiPro, GeminiCLI])
 )
 
 gemini_2_5_pro = Model(
     name          = 'gemini-2.5-pro',
     base_provider = 'Google',
-    best_provider = IterListProvider([Gemini])
+    best_provider = IterListProvider([Gemini, GeminiPro, GeminiCLI])
 )
 
 # codegemma
@@ -735,7 +753,7 @@ qwq_32b = Model(
 deepseek_v3 = Model(
     name = 'deepseek-v3',
     base_provider = 'DeepSeek',
-    best_provider = IterListProvider([DeepInfraChat, PollinationsAI, Together])
+    best_provider = IterListProvider([DeepInfraChat, Together])
 )
 
 # deepseek-r1
@@ -792,7 +810,7 @@ deepseek_prover_v2_671b = Model(
 deepseek_v3_0324 = Model(
     name = 'deepseek-v3-0324',
     base_provider = 'DeepSeek',
-    best_provider = IterListProvider([DeepInfraChat, LambdaChat, PollinationsAI])
+    best_provider = IterListProvider([DeepInfraChat, LambdaChat])
 )
 
 deepseek_v3_0324_turbo = Model(
@@ -805,7 +823,7 @@ deepseek_v3_0324_turbo = Model(
 deepseek_r1_0528 = Model(
     name = 'deepseek-r1-0528',
     base_provider = 'DeepSeek',
-    best_provider = IterListProvider([DeepInfraChat, LambdaChat])
+    best_provider = IterListProvider([DeepInfraChat, LambdaChat, PollinationsAI])
 )
 
 deepseek_r1_0528_turbo = Model(
@@ -834,18 +852,19 @@ grok_3 = Model(
     best_provider = Grok
 )
 
-grok_3_mini = Model(
-    name = 'grok-3-mini',
-    base_provider = 'x.ai',
-    best_provider = PollinationsAI
-)
-
 grok_3_r1 = Model(
     name = 'grok-3-r1',
     base_provider = 'x.ai',
     best_provider = Grok
 )
 
+kimi = Model(
+    name = 'kimi-k2',
+    base_provider = 'kimi.com',
+    best_provider = IterListProvider([Kimi, HuggingFace, DeepInfraChat, Groq]),
+    long_name = "moonshotai/Kimi-K2-Instruct"
+)
+
 ### Perplexity AI ### 
 sonar = Model(
     name = 'sonar',
@@ -990,9 +1009,9 @@ flux_canny = ImageModel(
 )
 
 flux_kontext_max = ImageModel(
-    name = 'flux-kontext-max',
+    name = 'flux-kontext',
     base_provider = 'Black Forest Labs',
-    best_provider = Together
+    best_provider = IterListProvider([PollinationsAI, Azure, LMArenaBeta, Together])
 )
 
 flux_dev_lora = ImageModel(
@@ -1001,18 +1020,6 @@ flux_dev_lora = ImageModel(
     best_provider = Together
 )
 
-flux_kontext_pro = ImageModel(
-    name = 'flux-kontext-pro',
-    base_provider = 'Black Forest Labs',
-    best_provider = Together
-)
-
-flux_kontext_dev = ImageModel(
-    name = 'flux-kontext-dev',
-    base_provider = 'Black Forest Labs',
-    best_provider = Together
-)
-
 class ModelUtils:
     """
     Utility class for mapping string identifiers to Model instances.
