@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import asyncio
-
+import random
 from asyncio import AbstractEventLoop
 from concurrent.futures import ThreadPoolExecutor
 from abc import abstractmethod
@@ -20,7 +20,8 @@ from .asyncio import get_running_loop, to_sync_generator, to_async_iterator
 from .response import BaseConversation, AuthResult
 from .helper import concat_chunks
 from ..cookies import get_cookies_dir
-from ..errors import ModelNotFoundError, ResponseError, MissingAuthError, NoValidHarFileError, PaymentRequiredError
+from ..errors import ModelNotFoundError, ResponseError, MissingAuthError, NoValidHarFileError, PaymentRequiredError, CloudflareError
+from .. import debug
 
 SAFE_PARAMETERS = [
     "model", "messages", "stream", "timeout",
@@ -368,7 +369,13 @@ class ProviderModelMixin:
         if not model and cls.default_model is not None:
             model = cls.default_model
         if model in cls.model_aliases:
-            model = cls.model_aliases[model]
+            alias = cls.model_aliases[model]
+            if isinstance(alias, list):
+                selected_model = random.choice(alias)
+                debug.log(f"{cls.__name__}: Selected model '{selected_model}' from alias '{model}'")
+                return selected_model
+            debug.log(f"{cls.__name__}: Using model '{alias}' for alias '{model}'")
+            return alias
         if model not in cls.model_aliases.values():
             if model not in cls.get_models(**kwargs) and cls.models:
                 raise ModelNotFoundError(f"Model not found: {model} in: {cls.__name__} Valid models: {cls.models}")
@@ -468,7 +475,7 @@ class AsyncAuthedProvider(AsyncGeneratorProvider, AuthFileMixin):
         try:
             auth_result = cls.get_auth_result()
             yield from to_sync_generator(cls.create_authed(model, messages, auth_result, **kwargs))
-        except (MissingAuthError, NoValidHarFileError):
+        except (MissingAuthError, NoValidHarFileError, CloudflareError):
             response = cls.on_auth(**kwargs)
             for chunk in response:
                 if isinstance(chunk, AuthResult):
@@ -495,7 +502,7 @@ class AsyncAuthedProvider(AsyncGeneratorProvider, AuthFileMixin):
             response = to_async_iterator(cls.create_authed(model, messages, **kwargs, auth_result=auth_result))
             async for chunk in response:
                 yield chunk
-        except (MissingAuthError, NoValidHarFileError):
+        except (MissingAuthError, NoValidHarFileError, CloudflareError):
             if cache_file.exists():
                 cache_file.unlink()
             response = cls.on_auth_async(**kwargs)
